==> visp_3.1.0.orig.tar.gz: visp-3.1.0/modules/robot/include/visp3/robot/vpRobotTemplate.h <==
/****************************************************************************
 *
 * This file is part of the ViSP software.
 * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file LICENSE.txt at the root directory of this source
 * distribution for additional information about the GNU GPL.
 *
 * For using ViSP with software that can not be combined with the GNU
 * GPL, please contact Inria about acquiring a ViSP Professional
 * Edition License.
 *
 * See http://visp.inria.fr for more information.
 *
 * This software was developed at:
 * Inria Rennes - Bretagne Atlantique
 * Campus Universitaire de Beaulieu
 * 35042 Rennes Cedex
 * France
 *
 * If you have questions regarding the use of this file, please contact
 * Inria at visp@inria.fr
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Description:
 * Defines a robot just to show which function you must implement.
 *
 * Authors:
 * Eric Marchand
 *
 *****************************************************************************/

#ifndef vpRobotTemplate_H
#define vpRobotTemplate_H

/*!
  \file vpRobotTemplate.h
  \brief class that defines a robot just to show which function you must
  implement
*/

#include <visp3/robot/vpRobot.h>

/*!
  \class vpRobotTemplate
  \ingroup group_robot_real_template
  \brief class that defines a robot just to show which function you must
  implement
*/

class VISP_EXPORT vpRobotTemplate : public vpRobot
{

public:
  //! basic initialization
  void init();

  //! constructor
  vpRobotTemplate();
  //! destructor
  virtual ~vpRobotTemplate();

  //! get the robot Jacobian expressed in the end-effector frame
  void get_eJe(vpMatrix &_eJe);
  //! get the robot Jacobian expressed in the robot reference frame
  void get_fJe(vpMatrix &_fJe);

  //! send to the controller a velocity expressed in the camera frame
  void sendCameraVelocity(const vpColVector &v);
  //! send to the controller a velocity expressed in the articular frame
  void sendArticularVelocity(const vpColVector &qdot);
  //! send to the controller a velocity (frame as to be specified)
  void setVelocity(const vpRobot::vpControlFrameType frame, const vpColVector &vel);

  //! get a position expressed in the robot reference frame
  void getPosition(vpPoseVector &q);
  //! get a position expressed in the articular frame
  void getArticularPosition(vpColVector &q);
  //! get a displacement (frame as to be specified)
  void getPosition(const vpRobot::vpControlFrameType frame, vpColVector &q);
  //! set a displacement (frame as to be specified)
  void setPosition(const vpRobot::vpControlFrameType frame, const vpColVector &q);

  //! get a displacement (frame as to be specified)
  void getDisplacement(const vpRobot::vpControlFrameType frame, vpColVector &q);
};

#endif

/*
 * Local variables:
 * c-basic-offset: 2
 * End:
 */

==> visp_3.5.0.orig.tar.gz: visp-3.5.0/modules/robot/include/visp3/robot/vpRobotTemplate.h <==
/****************************************************************************
 *
 * ViSP, open source Visual Servoing Platform software.
 * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file LICENSE.txt at the root directory of this source
 * distribution for additional information about the GNU GPL.
 *
 * For using ViSP with software that can not be combined with the GNU
 * GPL, please contact Inria about acquiring a ViSP Professional
 * Edition License.
 *
 * See http://visp.inria.fr for more information.
 *
 * This software was developed at:
 * Inria Rennes - Bretagne Atlantique
 * Campus Universitaire de Beaulieu
 * 35042 Rennes Cedex
 * France
 *
 * If you have questions regarding the use of this file, please contact
 * Inria at visp@inria.fr
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Description:
 * Defines a robot just to show which function you must implement.
 *
 * Authors:
 * Eric Marchand
 * Fabien Spindler
 *
 *****************************************************************************/

#ifndef vpRobotTemplate_h
#define vpRobotTemplate_h

/*!
  \file vpRobotTemplate.h
  Defines a robot just to show which function you must implement.
*/

#include <visp3/core/vpConfig.h>


#include <visp3/core/vpHomogeneousMatrix.h>
#include <visp3/robot/vpRobot.h>

/*!

  \class vpRobotTemplate
  \ingroup group_robot_real_template
  \brief Class that defines a robot just to show which function you must implement.

*/
class VISP_EXPORT vpRobotTemplate : public vpRobot
{
public:
  vpRobotTemplate();
  virtual ~vpRobotTemplate();

  void get_eJe(vpMatrix &eJe_);
  void get_fJe(vpMatrix &fJe_);

  /*!
    Return constant transformation between end-effector and tool frame.
    If your tool is a camera, this transformation is obtained by hand-eye calibration.
   */
  vpHomogeneousMatrix get_eMc() const { return m_eMc; }

  void getDisplacement(const vpRobot::vpControlFrameType frame, vpColVector &q);
  void getPosition(const vpRobot::vpControlFrameType frame, vpColVector &q);

  /*!
    Set constant transformation between end-effector and tool frame.
    If your tool is a camera, this transformation is obtained by hand-eye calibration.
   */
  void set_eMc(vpHomogeneousMatrix &eMc) { m_eMc = eMc; }
  void setPosition(const vpRobot::vpControlFrameType frame, const vpColVector &q);
  void setVelocity(const vpRobot::vpControlFrameType frame, const vpColVector &vel);

protected:
  void init();
  void getJointPosition(vpColVector &q);
  void setCartVelocity(const vpRobot::vpControlFrameType frame, const vpColVector &v);
  void setJointVelocity(const vpColVector &qdot);

protected:
  vpHomogeneousMatrix m_eMc; //!< Constant transformation between end-effector and tool (or camera) frame
};

#endif
